unit api;

interface

uses windows;//,shellapi;

//---------------------------------------------------------------------

type PROCESSOR_POWER_INFORMATION = record
  Number, //The system processor number.
  MaxMhz, //The maximum specified clock frequency of the system processor, in megahertz.
  CurrentMhz, //The processor clock frequency, in megahertz. This number is
  //the maximum specified processor clock frequency multiplied by the current processor throttle.
  MhzLimit, //The limit on the processor clock frequency, in megahertz. This
  //number is the maximum specified processor clock frequency multiplied by
  //the current processor thermal throttle limit.
  MaxIdleState, //The maximum idle state of this processor.
  CurrentIdleState : ULONG; //The current idle state of this processor.
end;
//Minimum supported client - Windows XP [desktop apps only]
//Minimum supported server -	Windows Server 2003 [desktop apps only]
//http://msdn.microsoft.com/en-us/library/aa373184.aspx


type SYSTEM_BATTERY_STATE = record
  AcOnLine, //If this member is TRUE, the system battery charger is currently
  //operating on external power
  BatteryPresent, //If this member is TRUE, at least one battery is present in the system.
  Charging, //If this member is TRUE, a battery is currently charging.
  Discharging : BOOLEAN; //If this member is TRUE, a battery is currently discharging.
  Spare1 : Array[0..3] of BOOLEAN; //Reserved.
  MaxCapacity, //The theoretical capacity of the battery when new, in mWh.
  RemainingCapacity, //The estimated remaining capacity of the battery, in mWh.
  Rate, //The current rate of discharge of the battery, in mW. A nonzero,
  //positive rate indicates charging; a negative rate indicates discharging.
  //Some batteries report only discharging rates.
  //This value should be treated as a LONG as it can contain negative values
  //(with the high bit set).
  EstimatedTime, //The estimated time remaining on the battery, in seconds.
  DefaultAlert1, //The manufacturer's suggestion of a capacity, in mWh, at
  //which a low battery alert should occur. Definitions of low vary from
  //manufacturer to manufacturer. In general, a warning state will occur
  //before a low state, but you should not assume that it always will. To
  //reduce risk of data loss, this value is usually used as the default
  //setting for the critical battery alarm.
  DefaultAlert2 : DWORD; //The manufacturer's suggestion of a capacity,
  //in mWh, at which a warning battery alert should occur. Definitions of
  //warning vary from manufacturer to manufacturer. In general, a warning
  //state will occur before a low state, but you should not assume that it
  //always will. To reduce risk of data loss, this value is usually used as
  //the default setting for the low battery alarm.
end;
//Minimum supported client - Windows XP [desktop apps only]
//Minimum supported server - Windows Server 2003 [desktop apps only]
//Header -	WinNT.h (include Windows.h)
//MSDN: http://msdn.microsoft.com/en-us/library/aa373212.aspx

//------------------------------------------------------------------------------



//CallNtPowerInformation function
//-------------------------------
//  NTSTATUS WINAPI CallNtPowerInformation(
//    _In_   POWER_INFORMATION_LEVEL InformationLevel,
//    _In_   PVOID lpInputBuffer,
//    _In_   ULONG nInputBufferSize,
//    _Out_  PVOID lpOutputBuffer,
//    _In_   ULONG nOutputBufferSize
//  );
//
//Sets or retrieves power information.
//
// InformationLevel [in]
// The information level requested. This value indicates the specific power
// information to be set or retrieved. This parameter must be one of the
// POWER_INFORMATION_LEVEL enumeration type values.
//
// lpInputBuffer [in]
// A pointer to an optional input buffer. The data type of this buffer depends on
// the information level requested in the InformationLevel parameter.
//
// nInputBufferSize [in]
// The size of the input buffer, in bytes.
//
// lpOutputBuffer [out]
// A pointer to an optional output buffer. The data type of this buffer depends on
// the information level requested in the InformationLevel parameter. If the buffer
// is too small to contain the information, the function returns STATUS_BUFFER_TOO_SMALL.
//
// nOutputBufferSize [in]
// The size of the output buffer, in bytes. Depending on the information level
// requested, this may be a variably sized buffer.
//
// Return value
// If the function succeeds, the return value is STATUS_SUCCESS.
// If the function fails, the return value can be one the following status codes.
// STATUS_BUFFER_TOO_SMALL - The output buffer is of insufficient size to contain
// the data to be returned.
// STATUS_ACCESS_DENIED - The caller had insufficient access rights to perform
// the requested action.
//
// Remarks
// Changes made to the current system power policy using CallNtPowerInformation
// are immediate, but they are not persistent; that is, the changes are not stored
// as part of a power scheme. Any changes to system power policy made with
// CallNtPowerInformation may be overwritten by changes to a policy scheme made
// by the user in the Power Options control panel program, or by subsequent calls
// to WritePwrScheme, SetActivePwrScheme, or other power scheme functions.
//
// Requirements
// Minimum supported client - Windows XP [desktop apps only]
// Minimum supported server - Windows Server 2003 [desktop apps only]
// Header - Powerbase.h;
//          PowrProf.h on Windows Server 2008 R2, Windows 7, Windows Server 2008,
//          Windows Vista, Windows Server 2003, and Windows XP
// Library - PowrProf.lib
// DLL - PowrProf.dll
//------------------------------------------------------------------------------
// MSDN: http://msdn.microsoft.com/en-us/library/aa372675.aspx
//------------------------------------------------------------------------------

function CallNtPowerInformation(InformationLevel: Integer;
          lpInputBuffer: Pointer;
          nInputBufferSize: Cardinal;
          lpOutputBuffer: Pointer;
          nOutputBufferSize: Cardinal): Cardinal; stdcall;
external 'PowrProf.dll' name 'CallNtPowerInformation';


implementation

end.
